%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                             %
% Model of Heat Transfer in a LIGO III System %
%       Between the Silicon Test Mass         %
%             And the Beam Tube               %
%                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear
close all

%%
%%% BASE VARIABLES %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

ri = 0.6225; %Radius of Beam Tube (m)
rj = 0.28; %Radius of Test Mass (m)
Ti = 295; %Temperature of Beam Tube (K)
Tj = 120; %Temperature of Test Mass (K)
Ei = 1; %Emissivity of Beam Tube
Ej = 0.1; %Emissivity of Test Mass
L = logspace(0,2,50); %Distance Between Discs (m)
SB = 5.6704e-8; %StefanBoltzmann Constant

%%
%%% CALCULATION %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

Ri = ri./L;
Rj = rj./L;
Sij = 1 + ((1 + Rj.^2)./(Ri.^2));
Vij = .5*(Sij - (Sij.^2 - 4*(rj/ri)^2).^.5); %View Factor of Beam Tube to Test Mass
Sji = 1 + ((1 + Ri.^2)./(Rj.^2));
Vji = .5*(Sji - (Sji.^2 - 4*(ri/rj)^2).^.5); %View Factor of Test Mass to Beam Tube

Pi = Ei*Ti^4*pi*ri^2*SB; %Total Power Emitted from the Beam Tube
Pj = Ej*Tj^4*pi*rj^2*SB; %Total Power Emitted from the Test Mass
Iij = Pi*Vij; %Total Power Incident on the Test Mass Face
Pij = Pi*Vij*Ej; %Power Emitted by the Beam Tube and Absorbed into the Test Mass
Pji = Pj*Vji*Ei; %Power Emitted by the Test Mass and Absorbed into the Beam Tube
Qij = Pij - Pji; %Net Heat Transfer between the Beam Tube and the Test Mass
Qj = Pij - Pj; %Net Heat gain/loss within the Silicon Mass

%%
%%% RESULTS %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

disp('The Total Power Emitted from the Beam Tube is');
disp(Pi);
disp('The Total Power Emitted from the Test Mass is');
disp(Pj);

%%
%%% GRAPH OF Vij%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Curve fit results for Vij
VijA = 0.05588;
VijB = -1.663;
VijC = -0.000282;
VijFit = VijA*L.^VijB + VijC;

figure
    semilogx(L,Vij,'-*',L,VijFit,'linewidth',3,'MarkerSize',10);
    grid on;
    set(gca,'fontsize',20);
    set(gcf,'Position',[150 150 1500 700]);
    xlabel ('Distance (m)');
    ylabel ('Proportion');
    title ('Proportion of Total Power Emitted by the Beam Tube Disk Face that arrives at the Test Mass Face (Vij) vs Distance (L)');
    legend('Model Data','Power Law Fit to Model');

%%
%%% GRAPH OF Pij and Iij %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Curve fit results for Pij
PijA =  2.921;
PijB = -1.663;
PijC = -0.01484;
PijFit = PijA*L.^PijB + PijC;

% Curve fit results for Iij
IijA = 29.21;
IijB = -1.663;
IijC = -0.1483;
IijFit = IijA*L.^IijB + IijC;

figure
    textsize = 20; linesize = 3;
    [AX,H1,H2] = plotyy(L,Pij,L,Iij,'semilogx');
    hold on
    H3 = line(L,PijFit,'Parent', AX(1));
    H4 = line(L,IijFit,'Parent', AX(2));
    grid on
    title('Power Absorbed (Pij) and Power Incident (Iij) on the Test Mass Face from the Beam Tube vs Distance (L)','FontSize',textsize)
    set(get(AX(1),'Ylabel'),'String','Absorbed Power (W)','FontSize',textsize)
    set(get(AX(2),'Ylabel'),'String','Incident Power (W)','FontSize',textsize)
    set(H1,'LineWidth',linesize)
    set(H2,'LineWidth',linesize)
    set(H3,'LineWidth',linesize)
    set(H4,'LineWidth',linesize)
    set(H1,'LineStyle','*','MarkerSize',10)
    set(H2,'LineStyle','*','MarkerSize',10)
    set(AX(1),'FontSize',textsize,'YLim',[-1,6],'YTick',linspace(-1,6,8))
    set(AX(2),'FontSize',textsize,'YLim',[-5,30],'YTick',linspace(-5,30,8))
    xlabel('Distance (m)')
    set(gcf,'Position',[150 150 1500 700]);
    legend('Model Data (Pij)','Power Law Fit to Model','Model Data (Iij)','Power Law Fit to Model');
    
% figure
%     semilogx(L,Pij,'-*',L,PijFit,'linewidth',3,'MarkerSize',10);
%     grid on;
%     set(gca,'fontsize',20);
%     set(gcf,'Position',[150 150 1500 700]);
%     xlabel ('Distance (m)');
%     ylabel ('Power (W)');
%     title ('Power Emitted by the Beam Tube Disk Face and Absorbed into the Test Mass Face (Pij) vs Distance (L)');
%     legend('Model Data','Power Law Fit to Model');

%%
%%% GRAPH OF Qij %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Curve fit values fed into cftool for Qij
%L = [1,2,3.5,3.69,3.7,5,10,20,100];
% Qij = [2.7590 0.8940 0.3136 0.2831 0.2817 0.1565 0.0397 0.0100 0.0004];

% Curve fit results for Qj
QijA = 2.841;
QijB = -1.663;
QijC = -0.01443;
QijFit = QijA*L.^QijB + QijC;

figure
    semilogx(L,Qij,'-*',L,QijFit,'linewidth',3,'MarkerSize',10);
    grid on;
    set(gca,'fontsize',20);
    set(gcf,'Position',[150 150 1500 700]);
    xlabel ('Distance (m)');
    ylabel ('Power (W)');
    title ('Net Power Transfer between the Beam Tube Disk Face and the Test Mass Face (Qij) vs Distance (L)');
    legend('Model Data','Power Law Fit to Model');
    
%%
%%% GRAPH OF Qj %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Curve fit values fed into cftool for Qj
%L = [1,2,3.5,3.69,3.7,5,10,20,100];
% Qj = [2.5471 0.6296 0.0328 0.0015 -2.0024e-5 -0.1286 -0.2488 -0.2794 -0.2892];

% Curve fit results for Qj
QjA = 2.921;
QjB = -1.663;
QjC = -0.3044;
QjFit = QjA*L.^QjB + QjC;

figure
    semilogx(L,Qj,'-*',L,QjFit,'linewidth',3,'MarkerSize',10);
    grid on;
    set(gca,'fontsize',20);
    set(gcf,'Position',[150 150 1500 700]);
    xlabel ('Distance (m)');
    ylabel ('Power (W)');
    title ('Net Power Gain/Loss of the Test Mass Face (Qj) vs Distance (L)');
    legend('Model Data','Power Law Fit to Model');